pub struct MockWorkspace { /* private fields */ }Expand description
A deterministic in-memory workspace for VFS and runtime tests.
Paths accepted by this type may be relative to the workspace root or already
absolute. File writes are upserts because Tinymist’s runtime-facing
FileChangeSet insert side also represents both creates and updates.
Implementations
Sourceimpl MockWorkspace
impl MockWorkspace
Sourcepub fn new(root: impl Into<PathBuf>) -> Self
pub fn new(root: impl Into<PathBuf>) -> Self
Creates an empty mock workspace at the given root.
Sourcepub fn builder(root: impl Into<PathBuf>) -> MockWorkspaceBuilder
pub fn builder(root: impl Into<PathBuf>) -> MockWorkspaceBuilder
Creates a builder for a mock workspace at the given root.
Sourcepub fn default_builder() -> MockWorkspaceBuilder
pub fn default_builder() -> MockWorkspaceBuilder
Creates a builder for a mock workspace at the default test root.
Sourcepub fn path(&self, path: impl AsRef<Path>) -> PathBuf
pub fn path(&self, path: impl AsRef<Path>) -> PathBuf
Resolves a test path against the workspace root.
Sourcepub fn immut_path(&self, path: impl AsRef<Path>) -> ImmutPath
pub fn immut_path(&self, path: impl AsRef<Path>) -> ImmutPath
Resolves a test path against the workspace root as an immutable path.
Sourcepub fn virtual_path(&self, path: impl AsRef<Path>) -> FileResult<VirtualPath>
pub fn virtual_path(&self, path: impl AsRef<Path>) -> FileResult<VirtualPath>
Resolves a test path as a Typst virtual path inside the workspace.
Sourcepub fn file_id(&self, path: impl AsRef<Path>) -> FileResult<FileId>
pub fn file_id(&self, path: impl AsRef<Path>) -> FileResult<FileId>
Resolves a test path as a workspace FileId.
Sourcepub fn access_model(&self) -> MockPathAccess
pub fn access_model(&self) -> MockPathAccess
Creates path access for a Tinymist VFS.
Sourcepub fn vfs(&self) -> Vfs<MockPathAccess>
pub fn vfs(&self) -> Vfs<MockPathAccess>
Creates a VFS backed by this workspace.
Sourcepub fn read(&self, path: impl AsRef<Path>) -> FileResult<Bytes>
pub fn read(&self, path: impl AsRef<Path>) -> FileResult<Bytes>
Reads bytes from the in-memory workspace.
Sourcepub fn contains(&self, path: impl AsRef<Path>) -> bool
pub fn contains(&self, path: impl AsRef<Path>) -> bool
Returns whether a file exists in the in-memory workspace.
Sourcepub fn write_source(
&self,
path: impl AsRef<Path>,
source: impl Into<String>,
) -> MockChange
pub fn write_source( &self, path: impl AsRef<Path>, source: impl Into<String>, ) -> MockChange
Creates or updates a Typst source file.
Sourcepub fn create_source(
&self,
path: impl AsRef<Path>,
source: impl Into<String>,
) -> MockChange
pub fn create_source( &self, path: impl AsRef<Path>, source: impl Into<String>, ) -> MockChange
Creates a Typst source file.
Sourcepub fn update_source(
&self,
path: impl AsRef<Path>,
source: impl Into<String>,
) -> MockChange
pub fn update_source( &self, path: impl AsRef<Path>, source: impl Into<String>, ) -> MockChange
Updates a Typst source file.
Sourcepub fn write_bytes(&self, path: impl AsRef<Path>, bytes: Bytes) -> MockChange
pub fn write_bytes(&self, path: impl AsRef<Path>, bytes: Bytes) -> MockChange
Creates or updates a file with arbitrary bytes.
Sourcepub fn remove(&self, path: impl AsRef<Path>) -> FileResult<MockChange>
pub fn remove(&self, path: impl AsRef<Path>) -> FileResult<MockChange>
Removes a file from the in-memory workspace.
Sourcepub fn rename(
&self,
from: impl AsRef<Path>,
to: impl AsRef<Path>,
) -> FileResult<MockChange>
pub fn rename( &self, from: impl AsRef<Path>, to: impl AsRef<Path>, ) -> FileResult<MockChange>
Renames a file inside the in-memory workspace.
Sourcepub fn sync_changeset(&self) -> FileChangeSet
pub fn sync_changeset(&self) -> FileChangeSet
Returns a changeset that syncs the current workspace files.
Sourcepub fn sync_filesystem_event(&self) -> FilesystemEvent
pub fn sync_filesystem_event(&self) -> FilesystemEvent
Returns a filesystem event that syncs the current workspace files.
Sourcepub fn sync_memory_event(&self) -> MemoryEvent
pub fn sync_memory_event(&self) -> MemoryEvent
Returns a memory event that syncs the current workspace files.